﻿using Dapper;
using Newtonsoft.Json;
using Oracle.ManagedDataAccess.Client;
using PreWODIQueries.Models;
using Syncfusion.EJ.Export;
using Syncfusion.JavaScript;
using Syncfusion.JavaScript.DataSources;
using Syncfusion.JavaScript.Models;
using Syncfusion.Linq;
using Syncfusion.XlsIO;
using System;
using System.Collections;
using System.Collections.Generic;
using System.Drawing;
using System.Linq;
using System.Reflection;
using System.Web;
using System.Web.Mvc;
using System.Web.Script.Serialization;

namespace PreWODIQueries.Controllers
{
    public class PlanController : Controller
    {
        private IEnumerable<ProdLineHierComboModel> GetProdLineHier()
        {
            List<ProdLineHierComboModel> retl = new List<ProdLineHierComboModel>();
            for (int i = 0; i < 5; i++)
            {
                retl.Add(new ProdLineHierComboModel { PRODLINE = $"Prodline #{i}" });
            }
            return retl;
        }

        //private IEnumerable<PlanData> GetPlanData(string prodLine)
        //{
        //    IEnumerable<PlanData> retl = null;
        //    string cmdStr = "SELECT pp.PRPLANID, pp.LOTNR, sa.MATERIALNR, pp.OPNR, SETUPSTART, " +
        //            "STARTTIME,  ENDTIME, NVL(pp.CONFIRMATIONNR,'') CONFIRMATIONNR, " +
        //            "pp.WORKCENTER, pp.WORKCENTERNAME, pr.PRODDESC, pp.QUANTITY, pr.LEADFRAME, pr.CORETYPE, pp.PRODUCTIONLINE, pr.TOOLTYPE,  pr.WIRETHICKNESS " +
        //            "FROM PLAN pp INNER JOIN PPCS_USR.SAP_AUFTRAG sa ON pp.LOTNR = TRIM(sa.AUFTRAGSNR) " +
        //            "INNER JOIN PRODUCTS pr ON TRIM(sa.MATERIALNR) = pr.PRODNR WHERE pp.PRODUCTIONLINE='" + prodLine + "'";
        //    try
        //    {
        //        using (OracleConnection con = new OracleConnection(Helpers.ConnSTr))
        //        {
        //            con.Open();
        //            retl = con.Query<PlanData>(cmdStr);
        //            con.Close();
        //        }
        //    }
        //    catch (Exception ex)
        //    {
        //        return null;
        //    }
        //    return retl;
        //}

        private IEnumerable<PlanData> GetPlanData(string prodLine)
        {
            DateTime stt = new DateTime(2017, 3, 1, 11, 2, 2);
            List<PlanData> retl = new List<PlanData>();
            for (int i = 0; i < 50; i++)
            {
                retl.Add(new PlanData
                {
                    PRODUCTIONLINE = $"Prodline #{i%5}",
                    LOTNr = $"LOTnr #{i}",
                    SETUPSTART = stt.AddMinutes(i*4),
                    STARTTIME = stt.AddMinutes( 15 + i * 4),
                    ENDTIME = stt.AddMinutes(65 + i * 4),
                });
            }
            return retl.Where(w => w.PRODUCTIONLINE == prodLine) ;
        }
        // GET: Plan
        public ActionResult PlanView()
        {
            ViewBag.ProdLineHierCombo = GetProdLineHier();
            Session["ProdLineHier"] = "-";
            return View();
        }

        public ActionResult GetDataSource(DataManager dm)
        {
            DataOperations  operation   = new DataOperations();
            var             prodline    = Session["ProdLineHier"].ToString();
            IEnumerable     Data        = GetPlanData(prodline).ToList();
            int count = Data.AsQueryable().Count();
            //Performing filtering operation
            if (dm.Where != null)
            {
                Data = operation.PerformWhereFilter(Data, dm.Where, "and");
                var filtered = (IEnumerable<object>)Data;
                count = filtered.Count();
            }
            //Performing sorting operation
            if (dm.Sorted != null)
                Data = operation.PerformSorting(Data, dm.Sorted);

            //Performing paging operations
            Data = operation.PerformSkip(Data, dm.Skip);
            Data = operation.PerformTake(Data, dm.Take);
            return Json(new { result = Data, count = count }, JsonRequestBehavior.AllowGet);
        }

        public ActionResult PlanProdHierChanged(DataManager dm, string prodline)
        {
            Session["ProdLineHier"] = prodline;
            return GetDataSource(dm);
        }

        public void ExportToExcel(string GridModel)
        {
            var             prodline    = Session["ProdLineHier"].ToString();
            ExcelExport     exp         = new ExcelExport();
            GridProperties  properties  = ConvertGridObject(GridModel);//(GridProperties)Syncfusion.JavaScript.Utils.DeserializeToModel(typeof(GridProperties), GridModel);
            var             DataSource  = GetPlanData(prodline);
            //properties.ServerExcelQueryCellInfo = QueryCellInfo;
            exp.Export(properties, DataSource, $"Terv_{prodline}.xlsx", ExcelVersion.Excel2010, false, false, "flat-saffron");
        }

        public void ExportToWord(string GridModel)
        {
            var             prodline    = Session["ProdLineHier"].ToString();
            WordExport      exp         = new WordExport();
            GridProperties  properties  = (GridProperties)Syncfusion.JavaScript.Utils.DeserializeToModel(typeof(GridProperties), GridModel);
            var             DataSource  = GetPlanData(prodline);
            exp.Export(properties, DataSource, $"Terv_{prodline}.docx", false, false, "flat-saffron");
        }

        public void ExportToPdf(string GridModel)
        {
            var             prodline    = Session["ProdLineHier"].ToString();
            PdfExport       exp         = new PdfExport();
            GridProperties  properties  = (GridProperties)Syncfusion.JavaScript.Utils.DeserializeToModel(typeof(GridProperties), GridModel);
            var             DataSource  = GetPlanData(prodline);
            exp.Export(properties, DataSource, $"Terv_{prodline}.pdf", false, false, true, "flat-saffron");
        }

        private GridProperties ConvertGridObject(string gridProperty)
        {
            GridProperties  gridProp    = (GridProperties) Utils.DeserializeToModel(typeof(GridProperties), gridProperty);
            GridExtensions  ext         = new GridExtensions();
            AutoFormat      auto        = new AutoFormat();
            auto.FontFamily             = "Arial";
            auto.ContentBorderColor     = Color.Brown;
            auto.ContentFontSize        = 10;
            auto.GCaptionBorderColor    = Color.Cornsilk;
            auto.GContentFontColor      = Color.DarkBlue;
            auto.HeaderFontSize         = 12;
            auto.HeaderBorderColor      = Color.Red;
            auto.ContentBgColor         = Color.Wheat;
            auto.GHeaderBgColor         = Color.Crimson;
            auto.AltRowBgColor          = Color.LightCyan;
            ext.SetTheme(auto, "flat-saffron");
            gridProp.AutoFormat         = auto;
            return gridProp;
        }
        public void QueryCellInfo(object currentCell)
        {
            IRange range = (IRange)currentCell;
            if (range.Column == 1 && int.Parse(range.Value) == 5)
                range.CellStyle.Color = Color.Red;
        }
    }
}